==> nextcloud-app-mail-1.7.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/fi.js <==
OC.L10N.register(
    "mail",
    {
    "Auto detect failed. Please use manual mode." : "Automaattinen havaitseminen epäonnistui. Käytä manuaalitilaa.",
    "Updating account failed: " : "Tilin päivittäminen epäonnistui:",
    "Creating account failed: " : "Tilin luominen epäonnistui:",
    "Embedded message %s" : "Upotettu viesti %s",
    "Important mail" : "Tärkeä sähköposti",
    "Mails" : "Sähköpostit",
    "Mail" : "Sähköposti",
    "💌 A mail app for Nextcloud" : "💌 Sähköpostisovellus Nextcloudille",
    "Auto" : "Automaattinen",
    "Name" : "Nimi",
    "Mail Address" : "Sähköpostiosoite",
    "Password" : "Salasana",
    "Manual" : "Manuaalinen",
    "IMAP Settings" : "IMAP-asetukset",
    "IMAP Host" : "IMAP-palvelin",
    "IMAP Security" : "IMAP-tietoturva",
    "None" : "Ei mitään",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP-portti",
    "IMAP User" : "IMAP-käyttäjä",
    "IMAP Password" : "IMAP-salasana",
    "SMTP Settings" : "SMTP-asetukset",
    "SMTP Host" : "SMTP-palvelin",
    "SMTP Security" : "SMTP-tietoturva",
    "SMTP Port" : "SMTP-portti",
    "SMTP User" : "SMTP-käyttäjä",
    "SMTP Password" : "SMTP-salasana",
    "Save" : "Tallenna",
    "Connect" : "Yhdistä",
    "Add alias" : "Lisää alias",
    "Add mail account" : "Lisää sähköpostitili",
    "Use Gravatar and favicon avatars" : "Käytä Gravatar- ja favicon-avatareja",
    "Register as application for mail links" : "Rekisteröi sovellukseksi mail-linkeille",
    "Show keyboard shortcuts" : "Näytä pikanäppäimet",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Salli sovelluksen kerätä tietoa vuorovaikutuksestasi. Tämän tiedon perusteella sovellus sopeutuu mieltymyksiisi. Nämä tiedot talletetaan vain paikallisesti.",
    "From" : "Lähettäjä",
    "Select account" : "Valitse tili",
    "To" : "Vastaanottaja",
    "Contact or email address …" : "Yhteystieto tai sähköpostiosoite…",
    "No contacts found." : "Yhteystietoja ei löytynyt.",
    "Subject" : "Aihe",
    "Subject …" : "Aihe…",
    "This message came from a noreply address so your reply will probably not be read." : "Tämä viesti saapui noreply-osoitteesta, joten vastaustasi ei luultavasti lueta.",
    "The following recipients do not have a PGP key: {recipients}." : "Seuraavilla vastaanottajilla ei ole PGP-avainta: {recipients}.",
    "Write message …" : "Kirjoita viesti…",
    "Saving draft …" : "Tallennetaan luonnosta…",
    "Draft saved" : "Luonnos tallennettu",
    "Upload attachment" : "Lähetä liite",
    "Add attachment from Files" : "Lisää liitteitä tiedostosovelluksesta",
    "Add attachment link from Files" : "Lisää liitelinkki tiedostosovelluksesta",
    "Enable formatting" : "Käytä muotoilua",
    "Encrypt message with Mailvelope" : "Salaa viesti Mailvelopella",
    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "Etsitkö tapaa salata sähköpostisi? Asenna Mailvelope-selainlaajennus!",
    "Uploading attachments …" : "Lähetetään liitteitä…",
    "Sending …" : "Lähetetään…",
    "Error sending your message" : "Virhe viestiäsi lähettäessä",
    "Go back" : "Takaisin",
    "Retry" : "Yritä uudelleen",
    "Message sent!" : "Viesti lähetetty!",
    "Write another message" : "Kirjoita toinen viesti",
    "Send" : "Lähetä",
    "Encrypt and send" : "Salaa ja lähetä",
    "Send unencrypted" : "Lähetä salaamattomana",
    "Uploading {percent}% …" : "Lähetetään {percent}% …",
    "Choose a file to add as attachment" : "Valitse liitteeksi lisättävä tiedosto",
    "Choose a file to share as a link" : "Valitse tiedosto, joka jaetaan linkkinä",
    "Writing mode" : "Kirjoitustila",
    "Preferred writing mode for new messages and replies." : "Ensisijainen kirjoitustila uusissa viesteissä ja vastauksissa.",
    "Plain text" : "Raakateksti",
    "No messages in this folder" : "Tässä kansiossa ei ole viestejä",
    "No messages" : "Ei viestejä",
    "Draft: " : "Luonnos: ",
    "Mark important" : "Merkitse tärkeäksi",
    "Mark favorite" : "Merkitse suosikiksi",
    "Mark unread" : "Merkitse lukemattomaksi",
    "Mark read" : "Merkitse luetuksi",
    "Mark as spam" : "Merkitse roskapostiksi",
    "Unselect" : "Poista valinta",
    "Select" : "Valitse",
    "Move" : "Siirrä",
    "Delete" : "Poista",
    "Blind copy recipients only" : "Vain piilokopion vastaanottajat",
    "Load more" : "Lataa lisää",
    "Report this bug" : "Ilmoita viasta",
    "Could not open mailbox" : "Postilaatikkoa ei voitu avata",
    "Loading messages" : "Ladataan viestejä",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Viestejäsi indeksoidaan. Tämä saattaa kestää hetken varsinkin suurikokoisissa postilaatikoissa.",
    "Choose target folder" : "Valitse kohdekansio",
    "No more subfolders in here" : "Täällä ei ole enempää alikansioita",
    "Choose" : "Valitse",
    "Important" : "Tärkeä",
    "Favorites" : "Suosikit",
    "Other" : "Muu",
    "Attachments" : "Liitteet",
    "Import into calendar" : "Tuo kalenteriin",
    "Download attachment" : "Lataa liite",
    "Save to Files" : "Tallenna tiedostoihin",
    "Unnamed" : "Nimetön",
    "Embedded message" : "Upotettu viesti",
    "Choose a folder to store the attachment in" : "Valitse kansio liitetiedoston tallentamiselle",
    "Save all to Files" : "Tallenna kaikki tiedostoihin",
    "Choose a folder to store the attachments in" : "Valitse kansio johon liitteet tallennetaan",
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Tämä viesti on salattu PGP:llä. Asenna Mailvelope purkaaksesi viestin salauksen.",
    "The images have been blocked to protect your privacy." : "Kuvat estettiin yksityisyytesi suojelemiseksi.",
    "Show images from this sender" : "Näytä kuvat tältä lähettäjältä",
    "New message" : "Uusi viesti",
    "Settings" : "Asetukset",
    "Quota" : "Kiintiö",
    "Account settings" : "Tilin asetukset",
    "Show only subscribed folders" : "Näytä vain tilatut kansiot",
    "Add folder" : "Lisää kansio",
    "Saving" : "Tallennetaan",
    "Move up" : "Siirrä ylös",
    "Move down" : "Siirrä alas",
    "Remove account" : "Poista tili",
    "Loading …" : "Ladataan…",
    "Not supported by the server" : "Ei tuettu palvelimen toimesta",
    "{usage} of {limit} used" : "{usage}/{limit} käytetty",
    "Remove account {email}" : "Poista tili {email}",
    "Remove {email}" : "Poista {email}",
    "Cancel" : "Peruuta",
    "Show all subscribed folders" : "Näytä kaikki tilatut kansiot",
    "Show all folders" : "Näytä kaikki kansiot",
    "Collapse folders" : "Supista kansiot",
    "Mark all as read" : "Merkitse kaikki luetuiksi",
    "Mark all messages of this mailbox as read" : "Merkitse kaikki tämän postilaatikon viestit luetuiksi",
    "Add subfolder" : "Lisää alikansio",
    "Edit name" : "Muokkaa nimeä",
    "Clear cache" : "Tyhjennä välimuisti",
    "Subscribed" : "Tilattu",
    "Delete folder" : "Poista kansio",
    "The folder and all messages in it will be deleted." : "Tämä kansio ja kaikki sen viestit poistetaan.",
    "Delete folder {name}" : "Poista kansio {name}",
    "An error occurred, unable to rename the mailbox." : "Tapahtui virhe. Postilaatikon nimeäminen uudelleen ei onnistunut.",
    "_{total} message_::_{total} messages_" : ["{total} viesti","{total} viestiä"],
    "Not found" : "Ei löytynyt",
    "Could not load your draft" : "Luonnosta ei voitu ladata",
    "Could not load original message" : "Alkuperäistä viestiä ei voitu ladata",
    "No message selected" : "Viestiä ei ole valittu",
    "Signature" : "Allekirjoitus",
    "A signature is added to the text of new messages and replies." : "Allekirjoitus lisätään uusien viestien ja vastausten tekstiosaan.",
    "Signature …" : "Allekirjoitus…",
    "Save signature" : "Tallenna allekirjoitus",
    "Could not load your message thread" : "Viestiketjua ei voitu ladata",
    "Reply" : "Vastaa",
    "Reply to sender only" : "Vastaa vain lähettäjälle",
    "Forward" : "Lähetä edelleen",
    "View source" : "Näytä lähde",
    "Message source" : "Viestin lähde",
    "Import into {calendar}" : "Tuo kalenteriin {calendar}",
    "Event imported into {calendar}" : "Tapahtuma tuotiin kalenteriin {calendar}",
    "Could not create event" : "Tapahtumaa ei voitu luoda",
    "Airplane" : "Lentokone",
    "Reservation {id}" : "Varaus {id}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Lento {flightNr} lentokentältä {depAirport} lentokentälle {arrAirport}",
    "Train" : "Juna",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} asemalta {depStation} asemalle {arrStation}",
    "Train from {depStation} to {arrStation}" : "Juna asemalta {depStation} asemalle {arrStation}",
    "Mail app" : "Sähköpostisovellus",
    "The mail app allows users to read mails on their IMAP accounts." : "Tämä sähköpostisovellus mahdollistaa käyttäjien lukea sähköpostiviestejä IMAP-tileiltä.",
    "Email: {email}" : "Sähköposti: {email}",
    "General" : "Yleiset",
    "Email address" : "Sähköpostiosoite",
    "IMAP" : "IMAP",
    "User" : "Käyttäjä",
    "Host" : "Palvelin",
    "Port" : "Portti",
    "SMTP" : "SMTP",
    "Apply and create/update for all users" : "Toteuta ja luo/päivitä kaikille käyttäjille",
    "With the settings above, the app will create account settings in the following way:" : "Sovellus luo tiliasetukset yllä olevin asetuksin seuraavasti:",
    "Change name" : "Vaihda nimi",
    "Mail server" : "Sähköpostipalvelin",
    "Set up an account" : "Määritä tili",
    "Keyboard shortcut" : "Näppäimistön pikanäppäin",
    "Keyboard shortcuts" : "Pikanäppäimet",
    "Speed up your Mail experience with these quick shortcuts." : "Nopeuta sähköpostikokemustasi näillä pikanäppäimillä.",
    "Compose new message" : "Uusi viesti",
    "Newer message" : "Uudempi",
    "Older message" : "Vanhempi viesti",
    "Toggle star" : "Lisää/poista tähti",
    "Toggle unread" : "Merkitse luetuksi/lukemattomaksi",
    "Search" : "Etsi",
    "Refresh" : "Päivitä",
    "Connect your mail account" : "Yhdistä sähköpostitilisi",
    "Unexpected error during account creation" : "Odottamaton virhe tilin luonnin aikanaa",
    "All" : "Kaikki",
    "Archive" : "Arkisto",
    "Drafts" : "Luonnokset",
    "All inboxes" : "Kaikki saapuneiden laatikot",
    "Inbox" : "Saapuneet",
    "Junk" : "Roskaposti",
    "Sent" : "Lähetetyt",
    "Trash" : "Roskakori",
    "Error while sharing file" : "Virhe tiedostoa jakaessa",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n uusi viesti \nlähettäjältä {from}","%n uutta viestiä \nlähettäjältä {from}"],
    "Nextcloud Mail" : "Nextcloud-sähköposti",
    "Could not load {tag}{name}{endtag}" : "{tag}{name}{endtag} ei voitu ladata",
    "There was a problem loading {tag}{name}{endtag}" : "Ladattaessa {tag}{name}{endtag} ilmeni ongelma",
    "Could not load your message" : "Viestiä ei voitu ladata",
    "Could not load the desired message" : "Haluttua viestiä ei voitu ladata",
    "Could not load the message" : "Viestiä ei voitu ladata",
    "Error loading message" : "Virhe viestiä ladatessa",
    "Forwarding to %s" : "Välitä viesti %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klikkaa jos sinua ei uudelleenohjata automaattisesti muutamaan sekuntiin.",
    "Redirect" : "Uudelleenohjaus",
    "The link leads to %s" : "Tämä linkki johtaa kohteeseen %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Jos et halua vierailla kyseisellä sivulla, voit palata <a href=\"%s\">sähköpostiin</a>.",
    "Continue to %s" : "Jatka sivulle %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-1.8.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/fi.js <==
OC.L10N.register(
    "mail",
    {
    "Auto detect failed. Please use manual mode." : "Automaattinen havaitseminen epäonnistui. Käytä manuaalitilaa.",
    "Updating account failed: " : "Tilin päivittäminen epäonnistui:",
    "Creating account failed: " : "Tilin luominen epäonnistui:",
    "Embedded message %s" : "Upotettu viesti %s",
    "Important mail" : "Tärkeä sähköposti",
    "Mails" : "Sähköpostit",
    "Mail" : "Sähköposti",
    "💌 A mail app for Nextcloud" : "💌 Sähköpostisovellus Nextcloudille",
    "Auto" : "Automaattinen",
    "Name" : "Nimi",
    "Mail Address" : "Sähköpostiosoite",
    "Password" : "Salasana",
    "Manual" : "Manuaalinen",
    "IMAP Settings" : "IMAP-asetukset",
    "IMAP Host" : "IMAP-palvelin",
    "IMAP Security" : "IMAP-tietoturva",
    "None" : "Ei mitään",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP-portti",
    "IMAP User" : "IMAP-käyttäjä",
    "IMAP Password" : "IMAP-salasana",
    "SMTP Settings" : "SMTP-asetukset",
    "SMTP Host" : "SMTP-palvelin",
    "SMTP Security" : "SMTP-tietoturva",
    "SMTP Port" : "SMTP-portti",
    "SMTP User" : "SMTP-käyttäjä",
    "SMTP Password" : "SMTP-salasana",
    "Save" : "Tallenna",
    "Connect" : "Yhdistä",
    "Account settings" : "Tilin asetukset",
    "Change name" : "Vaihda nimi",
    "Signature" : "Allekirjoitus",
    "A signature is added to the text of new messages and replies." : "Allekirjoitus lisätään uusien viestien ja vastausten tekstiosaan.",
    "Writing mode" : "Kirjoitustila",
    "Preferred writing mode for new messages and replies." : "Ensisijainen kirjoitustila uusissa viesteissä ja vastauksissa.",
    "Mail server" : "Sähköpostipalvelin",
    "Add alias" : "Lisää alias",
    "Add mail account" : "Lisää sähköpostitili",
    "Use Gravatar and favicon avatars" : "Käytä Gravatar- ja favicon-avatareja",
    "Register as application for mail links" : "Rekisteröi sovellukseksi mail-linkeille",
    "Show keyboard shortcuts" : "Näytä pikanäppäimet",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Salli sovelluksen kerätä tietoa vuorovaikutuksestasi. Tämän tiedon perusteella sovellus sopeutuu mieltymyksiisi. Nämä tiedot talletetaan vain paikallisesti.",
    "From" : "Lähettäjä",
    "Select account" : "Valitse tili",
    "To" : "Vastaanottaja",
    "Contact or email address …" : "Yhteystieto tai sähköpostiosoite…",
    "+ Cc/Bcc" : "+ Cc/Bcc",
    "Cc" : "Cc",
    "No contacts found." : "Yhteystietoja ei löytynyt.",
    "Bcc" : "Bcc",
    "Subject" : "Aihe",
    "Subject …" : "Aihe…",
    "This message came from a noreply address so your reply will probably not be read." : "Tämä viesti saapui noreply-osoitteesta, joten vastaustasi ei luultavasti lueta.",
    "The following recipients do not have a PGP key: {recipients}." : "Seuraavilla vastaanottajilla ei ole PGP-avainta: {recipients}.",
    "Write message …" : "Kirjoita viesti…",
    "Can not save draft because this account does not have a drafts mailbox configured." : "Ei voida tallentaa luonnosta, koska tälle käyttäjälle ei ole määritelty postilaatikkoa luonnoksille.",
    "Saving draft …" : "Tallennetaan luonnosta…",
    "Draft saved" : "Luonnos tallennettu",
    "Upload attachment" : "Lähetä liite",
    "Add attachment from Files" : "Lisää liitteitä tiedostosovelluksesta",
    "Enable formatting" : "Käytä muotoilua",
    "Encrypt message with Mailvelope" : "Salaa viesti Mailvelopella",
    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "Etsitkö tapaa salata sähköpostisi? Asenna Mailvelope-selainlaajennus!",
    "Uploading attachments …" : "Lähetetään liitteitä…",
    "Sending …" : "Lähetetään…",
    "Error sending your message" : "Virhe viestiäsi lähettäessä",
    "Go back" : "Takaisin",
    "Retry" : "Yritä uudelleen",
    "Message sent!" : "Viesti lähetetty!",
    "Write another message" : "Kirjoita toinen viesti",
    "Send" : "Lähetä",
    "Encrypt and send" : "Salaa ja lähetä",
    "Send unencrypted" : "Lähetä salaamattomana",
    "No sent mailbox configured. Please pick one in the account settings." : "Ei postilaatikkoa lähetetyille määritetty. Valitse se tilin asetuksista.",
    "Uploading {percent}% …" : "Lähetetään {percent}% …",
    "Choose a file to add as attachment" : "Valitse liitteeksi lisättävä tiedosto",
    "Choose a file to share as a link" : "Valitse tiedosto, joka jaetaan linkkinä",
    "Set up an account" : "Määritä tili",
    "Plain text" : "Raakateksti",
    "No messages" : "Ei viestejä",
    "Draft: " : "Luonnos: ",
    "Mark important" : "Merkitse tärkeäksi",
    "Mark favorite" : "Merkitse suosikiksi",
    "Mark unread" : "Merkitse lukemattomaksi",
    "Mark read" : "Merkitse luetuksi",
    "Mark as spam" : "Merkitse roskapostiksi",
    "Unselect" : "Poista valinta",
    "Select" : "Valitse",
    "Move" : "Siirrä",
    "Edit as new message" : "Muokkaa uutena viestinä",
    "Delete" : "Poista",
    "Blind copy recipients only" : "Vain piilokopion vastaanottajat",
    "Could not delete message" : "Ei voitu poistaa viestiä",
    "Mark {number} unread" : "Merkkaa {number} lukemattomiksi",
    "Mark {number} read" : "Merkkaa {number} luetuiksi",
    "Favorite {number}" : "Merkkaa {number} suosikeiksi",
    "Move {number}" : "Siirrä {number} viestiä",
    "Delete {number}" : "Poista {number} viestiä",
    "Load more" : "Lataa lisää",
    "Report this bug" : "Ilmoita viasta",
    "Could not open mailbox" : "Postilaatikkoa ei voitu avata",
    "Loading messages" : "Ladataan viestejä",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "Viestejäsi indeksoidaan. Tämä saattaa kestää hetken varsinkin suurikokoisissa postilaatikoissa.",
    "Choose" : "Valitse",
    "Important info" : "Tärkeää tietoa",
    "Favorites" : "Suosikit",
    "Other" : "Muu",
    "Attachments" : "Liitteet",
    "Import into calendar" : "Tuo kalenteriin",
    "Download attachment" : "Lataa liite",
    "Save to Files" : "Tallenna tiedostoihin",
    "Unnamed" : "Nimetön",
    "Embedded message" : "Upotettu viesti",
    "Choose a folder to store the attachment in" : "Valitse kansio liitetiedoston tallentamiselle",
    "Save all to Files" : "Tallenna kaikki tiedostoihin",
    "Choose a folder to store the attachments in" : "Valitse kansio johon liitteet tallennetaan",
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "Tämä viesti on salattu PGP:llä. Asenna Mailvelope purkaaksesi viestin salauksen.",
    "The images have been blocked to protect your privacy." : "Kuvat estettiin yksityisyytesi suojelemiseksi.",
    "Show images from this sender" : "Näytä kuvat tältä lähettäjältä",
    "Message frame" : "Viestiruutu",
    "Quoted text" : "Lainattu teksti",
    "Moving" : "Siirretään",
    "New message" : "Uusi viesti",
    "Settings" : "Asetukset",
    "Quota" : "Kiintiö",
    "Saving" : "Tallennetaan",
    "Move up" : "Siirrä ylös",
    "Move down" : "Siirrä alas",
    "Remove account" : "Poista tili",
    "Loading …" : "Ladataan…",
    "Not supported by the server" : "Ei tuettu palvelimen toimesta",
    "{usage} of {limit} used" : "{usage}/{limit} käytetty",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Tili {email} ja tallennetut viesti poistetaan Nextcloudista, muttei sähköpostintarjoajaltasi.",
    "Remove account {email}" : "Poista tili {email}",
    "Remove {email}" : "Poista {email}",
    "Cancel" : "Peruuta",
    "Mark all as read" : "Merkitse kaikki luetuiksi",
    "Mark all messages of this mailbox as read" : "Merkitse kaikki tämän postilaatikon viestit luetuiksi",
    "Edit name" : "Muokkaa nimeä",
    "Clear cache" : "Tyhjennä välimuisti",
    "Clear locally cached data, in case there are issues with synchronization." : "Poista paikallisesti tallennetut tiedot, jos synkronoinnissa on ongelmia.",
    "Subscribed" : "Tilattu",
    "Sync in background" : "Synkronoi taustalla",
    "An error occurred, unable to rename the mailbox." : "Tapahtui virhe. Postilaatikon nimeäminen uudelleen ei onnistunut.",
    "_{total} message_::_{total} messages_" : ["{total} viesti","{total} viestiä"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} lukematonta {total} viestistä","{unread} lukematonta {total} viestistä"],
    "Not found" : "Ei löytynyt",
    "Attachments were not copied. Please add them manually." : "Liitetiedostoja ei kopiotu. Lisää ne manuaalisesti.",
    "Could not load your draft" : "Luonnosta ei voitu ladata",
    "Could not load original message" : "Alkuperäistä viestiä ei voitu ladata",
    "No message selected" : "Viestiä ei ole valittu",
    "Signature …" : "Allekirjoitus…",
    "Save signature" : "Tallenna allekirjoitus",
    "Could not load your message thread" : "Viestiketjua ei voitu ladata",
    "Reply" : "Vastaa",
    "Reply to sender only" : "Vastaa vain lähettäjälle",
    "Forward" : "Lähetä edelleen",
    "View source" : "Näytä lähde",
    "Message source" : "Viestin lähde",
    "Import into {calendar}" : "Tuo kalenteriin {calendar}",
    "Event imported into {calendar}" : "Tapahtuma tuotiin kalenteriin {calendar}",
    "Could not create event" : "Tapahtumaa ei voitu luoda",
    "Airplane" : "Lentokone",
    "Reservation {id}" : "Varaus {id}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Lento {flightNr} lentokentältä {depAirport} lentokentälle {arrAirport}",
    "Train" : "Juna",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} asemalta {depStation} asemalle {arrStation}",
    "Train from {depStation} to {arrStation}" : "Juna asemalta {depStation} asemalle {arrStation}",
    "Mail app" : "Sähköpostisovellus",
    "The mail app allows users to read mails on their IMAP accounts." : "Tämä sähköpostisovellus mahdollistaa käyttäjien lukea sähköpostiviestejä IMAP-tileiltä.",
    "Email: {email}" : "Sähköposti: {email}",
    "General" : "Yleiset",
    "Email address" : "Sähköpostiosoite",
    "IMAP" : "IMAP",
    "User" : "Käyttäjä",
    "Host" : "Palvelin",
    "Port" : "Portti",
    "SMTP" : "SMTP",
    "Apply and create/update for all users" : "Toteuta ja luo/päivitä kaikille käyttäjille",
    "With the settings above, the app will create account settings in the following way:" : "Sovellus luo tiliasetukset yllä olevin asetuksin seuraavasti:",
    "Keyboard shortcut" : "Näppäimistön pikanäppäin",
    "Keyboard shortcuts" : "Pikanäppäimet",
    "Speed up your Mail experience with these quick shortcuts." : "Nopeuta sähköpostikokemustasi näillä pikanäppäimillä.",
    "Compose new message" : "Uusi viesti",
    "Newer message" : "Uudempi",
    "Older message" : "Vanhempi viesti",
    "Toggle star" : "Lisää/poista tähti",
    "Toggle unread" : "Merkitse luetuksi/lukemattomaksi",
    "Search" : "Etsi",
    "Refresh" : "Päivitä",
    "Connect your mail account" : "Yhdistä sähköpostitilisi",
    "Unexpected error during account creation" : "Odottamaton virhe tilin luonnin aikanaa",
    "All" : "Kaikki",
    "Archive" : "Arkisto",
    "Drafts" : "Luonnokset",
    "All inboxes" : "Kaikki saapuneiden laatikot",
    "Inbox" : "Saapuneet",
    "Junk" : "Roskaposti",
    "Sent" : "Lähetetyt",
    "Trash" : "Roskakori",
    "Error while sharing file" : "Virhe tiedostoa jakaessa",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n uusi viesti \nlähettäjältä {from}","%n uutta viestiä \nlähettäjältä {from}"],
    "Nextcloud Mail" : "Nextcloud-sähköposti",
    "Could not load {tag}{name}{endtag}" : "{tag}{name}{endtag} ei voitu ladata",
    "There was a problem loading {tag}{name}{endtag}" : "Ladattaessa {tag}{name}{endtag} ilmeni ongelma",
    "Could not load your message" : "Viestiä ei voitu ladata",
    "Could not load the desired message" : "Haluttua viestiä ei voitu ladata",
    "Could not load the message" : "Viestiä ei voitu ladata",
    "Error loading message" : "Virhe viestiä ladatessa",
    "Forwarding to %s" : "Välitä viesti %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klikkaa jos sinua ei uudelleenohjata automaattisesti muutamaan sekuntiin.",
    "Redirect" : "Uudelleenohjaus",
    "The link leads to %s" : "Tämä linkki johtaa kohteeseen %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Jos et halua vierailla kyseisellä sivulla, voit palata <a href=\"%s\">sähköpostiin</a>.",
    "Continue to %s" : "Jatka sivulle %s"
},
"nplurals=2; plural=(n != 1);");
